Class: Spidra::Resources::Logs
- Inherits:
-
Object
- Object
- Spidra::Resources::Logs
- Defined in:
- lib/spidra/resources/logs.rb
Instance Method Summary collapse
-
#get(log_id) ⇒ Object
Get the full details of a single log entry, including AI extraction output.
-
#initialize(http) ⇒ Logs
constructor
A new instance of Logs.
-
#list(filters = {}) ⇒ Object
List scrape logs with optional filters.
Constructor Details
#initialize(http) ⇒ Logs
Returns a new instance of Logs.
4 5 6 |
# File 'lib/spidra/resources/logs.rb', line 4 def initialize(http) @http = http end |
Instance Method Details
#get(log_id) ⇒ Object
Get the full details of a single log entry, including AI extraction output.
16 17 18 |
# File 'lib/spidra/resources/logs.rb', line 16 def get(log_id) @http.get("/scrape-logs/#{log_id}") end |
#list(filters = {}) ⇒ Object
List scrape logs with optional filters.
11 12 13 |
# File 'lib/spidra/resources/logs.rb', line 11 def list(filters = {}) @http.get("/scrape-logs", filters) end |