Class: Spidra::Resources::Usage
- Inherits:
-
Object
- Object
- Spidra::Resources::Usage
- Defined in:
- lib/spidra/resources/usage.rb
Instance Method Summary collapse
-
#get(range = "7d") ⇒ Object
Get credit and request usage broken down by day or week.
-
#initialize(http) ⇒ Usage
constructor
A new instance of Usage.
Constructor Details
#initialize(http) ⇒ Usage
Returns a new instance of Usage.
4 5 6 |
# File 'lib/spidra/resources/usage.rb', line 4 def initialize(http) @http = http end |
Instance Method Details
#get(range = "7d") ⇒ Object
Get credit and request usage broken down by day or week.
11 12 13 |
# File 'lib/spidra/resources/usage.rb', line 11 def get(range = "7d") @http.get("/usage-stats", range: range) end |